==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/KeyEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { KeyEventArgsDescription } from "./KeyEventArgsDescription";
/**
 * @hidden
 */
var KeyEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(KeyEventArgsDescriptionMetadata, _super);
    function KeyEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    KeyEventArgsDescriptionMetadata.b = function (a) {
        if (KeyEventArgsDescriptionMetadata.a == null) {
            KeyEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            KeyEventArgsDescriptionMetadata.c(KeyEventArgsDescriptionMetadata.a);
        }
        if (a.g(KeyEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(KeyEventArgsDescriptionMetadata.a);
    };
    KeyEventArgsDescriptionMetadata.c = function (a) {
    };
    KeyEventArgsDescriptionMetadata.d = function (a) {
        KeyEventArgsDescriptionMetadata.b(a);
        a.u("KeyEventArgs", function () { return new KeyEventArgsDescription(); });
        a.t("KeyEventArgs", KeyEventArgsDescriptionMetadata.a);
    };
    KeyEventArgsDescriptionMetadata.$t = markType(KeyEventArgsDescriptionMetadata, 'KeyEventArgsDescriptionMetadata');
    KeyEventArgsDescriptionMetadata.a = null;
    return KeyEventArgsDescriptionMetadata;
}(Base));
export { KeyEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/KeyEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { KeyEventArgsDescription } from "./KeyEventArgsDescription";
/**
 * @hidden
 */
var KeyEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(KeyEventArgsDescriptionMetadata, _super);
    function KeyEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    KeyEventArgsDescriptionMetadata.b = function (a) {
        if (KeyEventArgsDescriptionMetadata.a == null) {
            KeyEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            KeyEventArgsDescriptionMetadata.c(KeyEventArgsDescriptionMetadata.a);
        }
        if (a.j(KeyEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(KeyEventArgsDescriptionMetadata.a);
    };
    KeyEventArgsDescriptionMetadata.c = function (a) {
    };
    KeyEventArgsDescriptionMetadata.d = function (a) {
        KeyEventArgsDescriptionMetadata.b(a);
        a.aa("KeyEventArgs", function () { return new KeyEventArgsDescription(); });
        a.z("KeyEventArgs", KeyEventArgsDescriptionMetadata.a);
    };
    KeyEventArgsDescriptionMetadata.$t = markType(KeyEventArgsDescriptionMetadata, 'KeyEventArgsDescriptionMetadata');
    KeyEventArgsDescriptionMetadata.a = null;
    return KeyEventArgsDescriptionMetadata;
}(Base));
export { KeyEventArgsDescriptionMetadata };
